changeset 8651:ab28a213b924 draft

(svn r12303) -Codechange: move IsValidTile() in a more suitable place and make it static inline
author glx <glx@openttd.org>
date Thu, 28 Feb 2008 00:10:08 +0000 (2008-02-28)
parents 2fa51e7b4d1f
children 16fe115a9342
files src/landscape.cpp src/landscape.h src/tile_map.h
diffstat 3 files changed, 19 insertions(+), 17 deletions(-) [+]
line wrap: on
line diff
--- a/src/landscape.cpp
+++ b/src/landscape.cpp
@@ -919,8 +919,3 @@
 		TileY(a) + (GB(r, 8, 8) * rn * 2 >> 8) - rn
 	));
 }
-
-bool IsValidTile(TileIndex tile)
-{
-	return (tile < MapSizeX() * MapMaxY() && TileX(tile) != MapMaxX());
-}
--- a/src/landscape.h
+++ b/src/landscape.h
@@ -26,8 +26,6 @@
 byte HighestSnowLine(void);
 void ClearSnowLine(void);
 
-bool IsValidTile(TileIndex tile);
-
 uint GetPartialZ(int x, int y, Slope corners);
 uint GetSlopeZ(int x, int y);
 void GetSlopeZOnEdge(Slope tileh, DiagDirection edge, int *z1, int *z2);
--- a/src/tile_map.h
+++ b/src/tile_map.h
@@ -107,6 +107,17 @@
 }
 
 /**
+ * Checks if a tile is valid
+ *
+ * @param tile The tile to check
+ * @return True if the tile is on the map and not one of MP_VOID.
+ */
+static inline bool IsValidTile(TileIndex tile)
+{
+	return tile < MapSize() && !IsTileType(tile, MP_VOID);
+}
+
+/**
  * Returns the owner of a tile
  *
  * This function returns the owner of a tile. This cannot used
@@ -115,14 +126,13 @@
  *
  * @param tile The tile to check
  * @return The owner of the tile
  * @pre tile < MapSize()
  * @pre The type of the tile must not be MP_HOUSE, MP_VOID and MP_INDUSTRY
  */
 static inline Owner GetTileOwner(TileIndex tile)
 {
-	assert(tile < MapSize());
+	assert(IsValidTile(tile));
 	assert(!IsTileType(tile, MP_HOUSE));
-	assert(!IsTileType(tile, MP_VOID));
 	assert(!IsTileType(tile, MP_INDUSTRY));
 
 	return (Owner)_m[tile].m1;
@@ -136,14 +146,13 @@
  *
  * @param tile The tile to change the owner status.
  * @param owner The new owner.
  * @pre tile < MapSize()
  * @pre The type of the tile must not be MP_HOUSE, MP_VOID and MP_INDUSTRY
  */
 static inline void SetTileOwner(TileIndex tile, Owner owner)
 {
-	assert(tile < MapSize());
+	assert(IsValidTile(tile));
 	assert(!IsTileType(tile, MP_HOUSE));
-	assert(!IsTileType(tile, MP_VOID));
 	assert(!IsTileType(tile, MP_INDUSTRY));
 
 	_m[tile].m1 = owner;
@@ -165,7 +174,7 @@
  * Set the tropic zone
  * @param tile the tile to set the zone of
  * @param type the new type
- * @pre assert(tile < MapSize());
+ * @pre tile < MapSize()
  */
 static inline void SetTropicZone(TileIndex tile, TropicZone type)
 {
@@ -176,7 +185,7 @@
 /**
  * Get the tropic zone
  * @param tile the tile to get the zone of
- * @pre assert(tile < MapSize());
+ * @pre tile < MapSize()
  * @return the zone type
  */
 static inline TropicZone GetTropicZone(TileIndex tile)
@@ -115,14 +126,13 @@
  * @param tile The tile to check
  * @return The owner of the tile
- * @pre tile < MapSize()
- * @pre The type of the tile must not be MP_HOUSE, MP_VOID and MP_INDUSTRY
+ * @pre IsValidTile(tile)
+ * @pre The type of the tile must not be MP_HOUSE and MP_INDUSTRY
  */
 static inline Owner GetTileOwner(TileIndex tile)
@@ -136,14 +146,13 @@
  * @param tile The tile to change the owner status.
  * @param owner The new owner.
- * @pre tile < MapSize()
- * @pre The type of the tile must not be MP_HOUSE, MP_VOID and MP_INDUSTRY
+ * @pre IsValidTile(tile)
+ * @pre The type of the tile must not be MP_HOUSE and MP_INDUSTRY
  */
 static inline void SetTileOwner(TileIndex tile, Owner owner)